.. _documentation:

.. SymPy documentation master file, created by sphinx-quickstart.py on Sat Mar 22 19:34:32 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. module:: sympy

Welcome to SymPy's documentation!
----------------------------------

A PDF version of these docs can be found `here <https://github.com/sympy/sympy/releases>`_.

`SymPy <https://sympy.org>`_ is a Python library for symbolic mathematics.
If you are new to SymPy, start with the :ref:`Tutorial <tutorial>`.

This is the central page for all of SymPy's documentation.

==================================================================

..  rst-class:: column

:ref:`SymPy Tutorials <tutorial>`
-------------------------------------------------------

Tutorials introduce Sympy features to people who are new to the project. It includes
installation instructons, a basic introduction to Sympy operations and common gotchas.


..  rst-class:: column

:ref:`How-to Guides <guides>`
-------------------------------------------------------

These are step-by-step intructions on how to do different key developer tasks. It details
instructions on installing SymPy from source for development. The development setup and workflow
is also discussed with elaborate details on debugging, building the docs, and general guidelines
on writing documentation and docstrings.


..  rst-class:: column clearfix

:ref:`Explanation <explanation>`
-------------------------------------------------------

Intermediate SymPy users and developers should reference this category of documentation
for common pitfalls and advanced topics. The core SymPy features like variables, functions,
symbolic expressions are detailed but it does not completely exhaust all SymPy operations.


..  rst-class:: column

:ref:`SymPy API Reference <reference>`
-------------------------------------------------------

This category has a detailed description of the SymPy API, it discusses
what the different functions and modules do, their arguments and return values.

..  rst-class:: clearfix row custom-headings

.. toctree::
   :hidden:

   tutorial/index.rst
   guides/index.rst
   explanation/index.rst
   reference/index.rst
   miscellaneous/index.rst
